sub

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Subscriber

type Subscriber struct {
	bindings.PubSubChannel
}

Subscriber's channel(nfrvr)

func NewSubscriber

func NewSubscriber(conn *amqp.Connection) (*Subscriber, error)

Create a freshly-baked subscriber(don't play god too much, those may be lightweight, yet not no-weight)

func (*Subscriber) Close

func (s *Subscriber) Close() error

Function to make consumer stop consuming early

func (*Subscriber) StartSubscriberFunc

func (s *Subscriber) StartSubscriberFunc(queue, consumer string, autoAck, exclusive, noLocal, noWait bool, args amqp.Table) (func(chan any), error)

Returns a function which takes in a chan, that should be placed in goroutine

Jump to